@@ -8,15 +8,15 @@
 
 /*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA.
@@ -140,7 +140,7 @@ ep_msg_new(void (*dispatch)(EPassMsg *))
 	msg->dispatch = dispatch;
 	msg->msg.reply_port = e_msgport_new();
 #ifdef ENABLE_THREADS
-	msg->ismain = pthread_self() == main_thread;
+	msg->ismain = pthread_equal(pthread_self(), main_thread);
 #else
 	msg->ismain = TRUE;
 #endif
